@@ -1,10 +1,10 @@
-/* -*- mode: c; c-basic-offset: 4; tab-width: 4; indent-tabs-mode: t -*-
+/*
  *
  * Conky, a system monitor, based on torsmo
  *
  * Please see COPYING for details
  *
- * Copyright (c) 2005-2012 Brenden Matthews, Philip Kovacs, et. al.
+ * Copyright (c) 2005-2019 Brenden Matthews, Philip Kovacs, et. al.
  *	(see AUTHORS)
  * All rights reserved.
  *
@@ -28,15 +28,25 @@
 #include <cairo.h>
 
 cairo_text_extents_t *create_cairo_text_extents_t(void) {
-	return calloc(1, sizeof(cairo_text_extents_t));
+  return calloc(1, sizeof(cairo_text_extents_t));
 }
 
 cairo_font_extents_t *create_cairo_font_extents_t(void) {
-	return calloc(1, sizeof(cairo_font_extents_t));
+  return calloc(1, sizeof(cairo_font_extents_t));
 }
 
 cairo_matrix_t *create_cairo_matrix_t(void) {
-	return calloc(1, sizeof(cairo_matrix_t));
+  return calloc(1, sizeof(cairo_matrix_t));
 }
 
+void destroy_cairo_text_extents_t(cairo_text_extents_t *pointer) {
+  free(pointer);
+}
+
+void destroy_cairo_font_extents_t(cairo_font_extents_t *pointer) {
+  free(pointer);
+}
+
+void destroy_cairo_matrix_t(cairo_matrix_t *pointer) { free(pointer); }
+
 #endif /* _LIBCAIRO_HELPER_H_ */
