@@ -1,5 +1,4 @@
-/* -*- mode: c; c-basic-offset: 4; tab-width: 4; indent-tabs-mode: t -*-
- * vim: ts=4 sw=4 noet ai cindent syntax=c
+/*
  *
  * Conky, a system monitor, based on torsmo
  *
@@ -10,7 +9,7 @@
  * Please see COPYING for details
  *
  * Copyright (c) 2004, Hannu Saransaari and Lauri Hakkarainen
- * Copyright (c) 2005-2012 Brenden Matthews, Philip Kovacs, et. al.
+ * Copyright (c) 2005-2019 Brenden Matthews, Philip Kovacs, et. al.
  *	(see AUTHORS)
  * All rights reserved.
  *
@@ -30,8 +29,8 @@
 #ifndef _BSDAPM_H
 #define _BSDAPM_H
 
-void print_apm_adapter(struct text_object *, char *, int);
-void print_apm_battery_life(struct text_object *, char *, int);
-void print_apm_battery_time(struct text_object *, char *, int);
+void print_apm_adapter(struct text_object *, char *, unsigned int);
+void print_apm_battery_life(struct text_object *, char *, unsigned int);
+void print_apm_battery_time(struct text_object *, char *, unsigned int);
 
 #endif /* _BSDAPM_H */
