@@ -1,5 +1,4 @@
-/* -*- mode: c++; c-basic-offset: 4; tab-width: 4; indent-tabs-mode: t -*-
- * vim: ts=4 sw=4 noet ai cindent syntax=cpp
+/*
  *
  * Conky, a system monitor, based on torsmo
  *
@@ -10,7 +9,7 @@
  * Please see COPYING for details
  *
  * Copyright (c) 2004, Hannu Saransaari and Lauri Hakkarainen
- * Copyright (c) 2005-2012 Brenden Matthews, Philip Kovacs, et. al.
+ * Copyright (c) 2005-2019 Brenden Matthews, Philip Kovacs, et. al.
  *	(see AUTHORS)
  * All rights reserved.
  *
@@ -33,9 +32,10 @@
 
 int update_entropy(void);
 
-void print_entropy_avail(struct text_object *, char *, int);
+void print_entropy_avail(struct text_object *, char *, unsigned int);
 uint8_t entropy_percentage(struct text_object *);
-void print_entropy_poolsize(struct text_object *, char *, int);
+void print_entropy_poolsize(struct text_object *, char *, unsigned int);
 double entropy_barval(struct text_object *);
+void print_password(struct text_object *, char *, unsigned int);
 
 #endif /* _ENTROPY_H */
