@@ -1,12 +1,11 @@
-/* -*- mode: c++; c-basic-offset: 4; tab-width: 4; indent-tabs-mode: t -*-
- * vim: ts=4 sw=4 noet ai cindent syntax=cpp
+/*
  *
  * Conky, a system monitor, based on torsmo
  *
  * Please see COPYING for details
  *
  * Copyright (c) 2007 Toni Spets
- * Copyright (c) 2005-2012 Brenden Matthews, Philip Kovacs, et. al.
+ * Copyright (c) 2005-2019 Brenden Matthews, Philip Kovacs, et. al.
  *	(see AUTHORS)
  * All rights reserved.
  *
@@ -29,6 +28,6 @@
 
 int update_hddtemp(void);
 void free_hddtemp(struct text_object *);
-void print_hddtemp(struct text_object *, char *, int);
+void print_hddtemp(struct text_object *, char *, unsigned int);
 
 #endif /*HDDTEMP_H_*/
