@@ -1,11 +1,10 @@
-/* -*- mode: c++; c-basic-offset: 4; tab-width: 4; indent-tabs-mode: t -*-
- * vim: ts=4 sw=4 noet ai cindent syntax=cpp
+/*
  *
  * Conky, a system monitor, based on torsmo
  *
  * Please see COPYING for details
  *
- * Copyright (c) 2005-2012 Brenden Matthews, Philip Kovacs, et. al.
+ * Copyright (c) 2005-2019 Brenden Matthews, Philip Kovacs, et. al.
  *	(see AUTHORS)
  * All rights reserved.
  *
@@ -26,8 +25,8 @@
 #ifndef IRC_H_
 #define IRC_H_
 
-void parse_irc_args(struct text_object *, const char*);
-void print_irc(struct text_object *, char *, int);
+void parse_irc_args(struct text_object *, const char *);
+void print_irc(struct text_object *, char *, unsigned int);
 void free_irc(struct text_object *);
 
 #endif /*IRC_H_*/
