@@ -61,6 +61,7 @@
 #define _LINUX_IF_H
 #endif
 #include <linux/route.h>
+#include <linux/version.h>
 #include <math.h>
 #include <pthread.h>
 #include <atomic>
@@ -179,11 +180,18 @@ int update_meminfo(void) {
   /* unsigned int a; */
   char buf[256];
 
-  unsigned long long shmem = 0, sreclaimable = 0;
+  /* With multi-threading, calculations that require
+   * multple steps to reach a final result can cause havok
+   * if the intermediary calculations are directly assigned to the
+   * information struct (they may be read by other functions in the meantime).
+   * These variables keep the calculations local to the function and finish off
+   * the function by assigning the results to the information struct */
+  unsigned long long shmem = 0, sreclaimable = 0, curmem = 0, curbufmem = 0,
+                     cureasyfree = 0, memavail = 0;
 
-  info.mem = info.memwithbuffers = info.memmax = info.memdirty = info.swap =
-      info.swapfree = info.swapmax = info.bufmem = info.buffers = info.cached =
-          info.memfree = info.memeasyfree = 0;
+  info.memmax = info.memdirty = info.swap = info.swapfree = info.swapmax =
+      info.memwithbuffers = info.buffers = info.cached = info.memfree =
+          info.memeasyfree = 0;
 
   if (!(meminfo_fp = open_file("/proc/meminfo", &reported))) { return 0; }
 
@@ -204,6 +212,8 @@ int update_meminfo(void) {
       sscanf(buf, "%*s %llu", &info.cached);
     } else if (strncmp(buf, "Dirty:", 6) == 0) {
       sscanf(buf, "%*s %llu", &info.memdirty);
+    } else if (strncmp(buf, "MemAvailable:", 13) == 0) {
+      sscanf(buf, "%*s %llu", &memavail);
     } else if (strncmp(buf, "Shmem:", 6) == 0) {
       sscanf(buf, "%*s %llu", &shmem);
     } else if (strncmp(buf, "SReclaimable:", 13) == 0) {
@@ -211,8 +221,8 @@ int update_meminfo(void) {
     }
   }
 
-  info.mem = info.memwithbuffers = info.memmax - info.memfree;
-  info.memeasyfree = info.memfree;
+  curmem = info.memwithbuffers = info.memmax - info.memfree;
+  cureasyfree = info.memfree;
   info.swap = info.swapmax - info.swapfree;
 
   /* Reclaimable memory: does not include shared memory, which is part of cached
@@ -220,17 +230,35 @@ int update_meminfo(void) {
      Note: when shared memory is swapped out, shmem decreases and swapfree
      decreases - we want this.
   */
-  info.bufmem = (info.cached - shmem) + info.buffers + sreclaimable;
+  curbufmem = (info.cached - shmem) + info.buffers + sreclaimable;
 
-  /* Now (info.mem - info.bufmem) is the *really used* (aka unreclaimable)
-     memory. When this value reaches the size of the physical RAM, and swap is
-     full or non-present, OOM happens. Therefore this is the value users want to
-     monitor, regarding their RAM.
-  */
+  /* Calculate the memory usage.
+   *
+   * The Linux Kernel introduced a new field for memory available,
+   * when possible, use that.
+   * https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=34e431b0ae398fc54ea69ff85ec700722c9da773
+   */
   if (no_buffers.get(*state)) {
-    info.mem -= info.bufmem;
-    info.memeasyfree += info.bufmem;
+#if LINUX_VERSION_CODE <= KERNEL_VERSION(3, 14, 0)
+    /* Now ('info.mem' - 'info.bufmem') is the *really used* (aka unreclaimable)
+       memory. When this value reaches the size of the physical RAM, and swap is
+       full or non-present, OOM happens. Therefore this is the value users want
+       to monitor, regarding their RAM.
+    */
+    curmem -= curbufmem;
+    cureasyfree += curbufmem;
+#else
+    curmem = info.memmax - memavail;
+    cureasyfree += curbufmem;
+#endif
   }
+
+  /* Now that we know that every calculation is finished we can wrap up
+   * by assigning the values to the information structure */
+  info.mem = curmem;
+  info.bufmem = curbufmem;
+  info.memeasyfree = cureasyfree;
+
   fclose(meminfo_fp);
   return 0;
 }
