@@ -1,10 +1,10 @@
-/* -*- mode: c; c-basic-offset: 4; tab-width: 4; indent-tabs-mode: t -*-
+/*
  *
  * Conky, a system monitor, based on torsmo
  *
  * Please see COPYING for details
  *
- * Copyright (c) 2005-2012 Brenden Matthews, Philip Kovacs, et. al.
+ * Copyright (c) 2005-2019 Brenden Matthews, Philip Kovacs, et. al.
  * Copyright (c) 2009 Yeon-Hyeong Yang <lbird94@gmail.com>
  *	(see AUTHORS)
  * All rights reserved.
@@ -31,6 +31,6 @@
 #ifndef _SONY_H
 #define _SONY_H
 
-void get_sony_fanspeed(struct text_object *, char *, int);
+void get_sony_fanspeed(struct text_object *, char *, unsigned int);
 
 #endif /* _SONY_H */
