@@ -1,5 +1,4 @@
-/* -*- mode: c; c-basic-offset: 4; tab-width: 4; indent-tabs-mode: t -*-
- * vim: ts=4 sw=4 noet ai cindent syntax=c
+/*
  *
  * Conky, a system monitor, based on torsmo
  *
@@ -10,7 +9,7 @@
  * Please see COPYING for details
  *
  * Copyright (c) 2004, Hannu Saransaari and Lauri Hakkarainen
- * Copyright (c) 2005-2012 Brenden Matthews, Philip Kovacs, et. al.
+ * Copyright (c) 2005-2019 Brenden Matthews, Philip Kovacs, et. al.
  *   (see AUTHORS)
  * All rights reserved.
  *
@@ -31,7 +30,7 @@
 #ifndef _USER_H
 #define _USER_H
 
-void print_gid_name(struct text_object *obj, char *p, int p_max_size);
-void print_uid_name(struct text_object *obj, char *p, int p_max_size);
+void print_gid_name(struct text_object *obj, char *p, unsigned int p_max_size);
+void print_uid_name(struct text_object *obj, char *p, unsigned int p_max_size);
 
 #endif /* _USER_H */
